pub struct FsInspectTree { /* private fields */ }Expand description
Maintains ownership of the various inspect nodes/properties. Will be removed from the root node they were attached to when dropped.
Implementations
Sourceimpl FsInspectTree
impl FsInspectTree
Sourcepub fn new(
fs: Weak<dyn FsInspect + Send + Sync + 'static>,
root: &Node,
) -> FsInspectTree
pub fn new( fs: Weak<dyn FsInspect + Send + Sync + 'static>, root: &Node, ) -> FsInspectTree
Attaches Inspect nodes following a standard hierarchy, returning ownership of the newly created LazyNodes.
Sourcepub fn register_volume(
self: &Arc<Self>,
name: String,
volume: Weak<dyn FsInspectVolume + Send + Sync + 'static>,
)
pub fn register_volume( self: &Arc<Self>, name: String, volume: Weak<dyn FsInspectVolume + Send + Sync + 'static>, )
Registers a provider for per-volume data. If volume is dropped, the node will remain
present in the inspect tree but yield no data, until Self::unregister_volume is called.
pub fn unregister_volume(&self, name: String)