pub trait FsInspect {
// Required methods
fn get_info_data(&self) -> InfoData;
fn get_usage_data<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = UsageData> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Trait that Rust filesystems should implement to expose required Inspect data.
Once implemented, a filesystem can attach the Inspect data to a given root node by calling
FsInspectTree::new which will return ownership of the attached nodes/properties.
Required Methods
fn get_info_data(&self) -> InfoData
fn get_usage_data<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = UsageData> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".